# file: squareTessellation.py
# author: Bob Muller
#
# CS1101 Computer Science I
#
# Python code for tessellating with squares.

from stddraw import *
import random

# A customized version of stddraw's filledRectangle function.
#
def filledRectangle(picture, x, y, width, height, color):
  halfWidth = width / 2
  halfHeight = height / 2
  picture.filledRectangle(x + halfWidth, y + halfHeight, halfWidth, halfHeight, color)

# stackOfSquares : stddraw.Picture * float * int -> void
#
# The call stackOfSquares(p, x, n) makes a column of n squares
# at x-coordinate x.
#
def stackOfSquares(picture, x, n):
  side = 1.0 / n
  def stackEmUp(m):
    if m > 0:
      y = (m - 1) * side
      color = picture.randomColor()
      filledRectangle(picture, x, y, side, side, color)
      stackEmUp(m - 1)
  stackEmUp(n)
  
def tessellateWithSquares(picture, n):
  side = 1.0 / n
  def layEmOut(m):
    if m > 0:
      x = (m - 1) * side
      stackOfSquares(picture, x, n)
      layEmOut(m - 1)
  layEmOut(n)

def testTessellateWithSquares():
  def responder(event):
    n = 1 + int(random.random() * 16)
    tessellateWithSquares(picture, n)

  picture = Picture()
  picture.setW(600)
  picture.setH(600)
  picture.bind('<Button-1>', responder)
  picture.start()

testTessellateWithSquares()
